@@ -3,11 +3,6 @@ from io import StringIO
 
 import pytest
 
-try:
-    import yaml
-except ImportError:
-    yaml = None
-
 from check_python_versions.parsers.appveyor import (
     appveyor_detect_py_version_pattern,
     appveyor_normalize_py_version,
@@ -16,10 +11,6 @@ from check_python_versions.parsers.appveyor import (
 )
 
 
-needs_pyyaml = pytest.mark.skipif(yaml is None, reason="PyYAML not installed")
-
-
-@needs_pyyaml
 def test_get_appveyor_yml_python_versions(tmp_path):
     appveyor_yml = tmp_path / "appveyor.yml"
     appveyor_yml.write_text(textwrap.dedent("""\
@@ -36,7 +27,6 @@ def test_get_appveyor_yml_python_versions(tmp_path):
     ]
 
 
-@needs_pyyaml
 def test_get_appveyor_yml_python_versions_forward_slashs(tmp_path):
     # Regr. test for https://github.com/mgedmin/check-python-versions/issues/12
     appveyor_yml = tmp_path / "appveyor.yml"
@@ -53,7 +43,6 @@ def test_get_appveyor_yml_python_versions_forward_slashs(tmp_path):
     ]
 
 
-@needs_pyyaml
 def test_get_appveyor_yml_python_versions_python_not_recognized(tmp_path):
     # Regr. test for https://github.com/mgedmin/check-python-versions/issues/12
     appveyor_yml = tmp_path / "appveyor.yml"
@@ -70,7 +59,6 @@ def test_get_appveyor_yml_python_versions_python_not_recognized(tmp_path):
     ]
 
 
-@needs_pyyaml
 def test_get_appveyor_yml_python_versions_using_toxenv(tmp_path):
     appveyor_yml = tmp_path / "appveyor.yml"
     appveyor_yml.write_text(textwrap.dedent("""\
@@ -90,6 +78,7 @@ def test_get_appveyor_yml_python_versions_using_toxenv(tmp_path):
     ('C:\\Python27\\', '2.7'),
     ('C:\\Python27-x64', '2.7'),
     ('C:\\PYTHON34-X64', '3.4'),
+    ('C:\\Python38-x64\\python.exe', '3.8'),
     ('c:/python38', '3.8'),
     ('c:/python3', None),  # would it be useful to return '3'?  probably not
     ('unknown', None),
