@@ -18,7 +18,7 @@ def test_get_tox_ini_python_versions(tmp_path):
     tox_ini = tmp_path / "tox.ini"
     tox_ini.write_text(textwrap.dedent("""\
         [tox]
-        envlist = py27,py36,py27-docs
+        envlist = py27,py36,py27-docs,pylint
     """))
     assert get_tox_ini_python_versions(tox_ini) == ['2.7', '3.6']
 
@@ -74,9 +74,11 @@ def test_brace_expand(s, expected):
 @pytest.mark.parametrize('s, expected', [
     ('py36', '3.6'),
     ('py37-lint', '3.7'),
+    ('py310', '3.10'),  # future-proofness!
     ('pypy', 'PyPy'),
     ('pypy3', 'PyPy3'),
-    ('flake8', 'flake8'),
+    ('pylint', None),
+    ('flake8', None),
 ])
 def test_tox_env_to_py_version(s, expected):
     assert tox_env_to_py_version(s) == expected
@@ -145,6 +147,8 @@ def test_update_tox_envlist_with_spaces():
     # followed by a space
     ('py27,\npy34,\npy35,\npypy3', 'py36,\npy37,\npypy3'),
     ('py27\npy34\npy35\npypy3', 'py36\npy37\npypy3'),
+    # uhh regression I guess
+    ('\npy27,py34,py35,pypy3', 'py36,py37,pypy3'),
 ])
 def test_update_tox_envlist_with_newlines(s, expected):
     result = update_tox_envlist(s, ['3.6', '3.7'])
