@@ -3,11 +3,6 @@ from io import StringIO
 
 import pytest
 
-try:
-    import yaml
-except ImportError:
-    yaml = None
-
 from check_python_versions.parsers.travis import (
     XENIAL_SUPPORTED_PYPY_VERSIONS,
     add_yaml_node,
@@ -19,10 +14,6 @@ from check_python_versions.parsers.travis import (
 )
 
 
-needs_pyyaml = pytest.mark.skipif(yaml is None, reason="PyYAML not installed")
-
-
-@needs_pyyaml
 def test_get_travis_yml_python_versions(tmp_path):
     travis_yml = tmp_path / ".travis.yml"
     travis_yml.write_text(textwrap.dedent("""\
@@ -46,7 +37,6 @@ def test_get_travis_yml_python_versions(tmp_path):
     ]
 
 
-@needs_pyyaml
 def test_get_travis_yml_python_versions_no_list(tmp_path):
     travis_yml = StringIO(textwrap.dedent("""\
         python: 3.7
@@ -57,7 +47,6 @@ def test_get_travis_yml_python_versions_no_list(tmp_path):
     ]
 
 
-@needs_pyyaml
 def test_get_travis_yml_python_versions_no_python_only_matrix(tmp_path):
     travis_yml = tmp_path / ".travis.yml"
     travis_yml.write_text(textwrap.dedent("""\
